@@ -6,8 +6,6 @@
 #ifndef ENA_PHC_H
 #define ENA_PHC_H
 
-#include "ena_netdev.h"
-
 #ifdef ENA_PHC_SUPPORT
 
 #include <linux/ptp_clock_kernel.h>
@@ -24,20 +22,29 @@ struct ena_phc_info {
 
 	/* PHC lock */
 	spinlock_t lock;
+
+	/* Enabled by kernel */
+	bool enabled;
 };
 
-bool ena_phc_enabled(struct ena_adapter *adapter);
+void ena_phc_enable(struct ena_adapter *adapter, bool enable);
+bool ena_phc_is_enabled(struct ena_adapter *adapter);
+bool ena_phc_is_active(struct ena_adapter *adapter);
 int ena_phc_get_index(struct ena_adapter *adapter);
 int ena_phc_init(struct ena_adapter *adapter);
 void ena_phc_destroy(struct ena_adapter *adapter);
-
+int ena_phc_alloc(struct ena_adapter *adapter);
+void ena_phc_free(struct ena_adapter *adapter);
 #else /* ENA_PHC_SUPPORT */
 
-static inline bool ena_phc_enabled(struct ena_adapter *adapter) {return false; }
+static inline void ena_phc_enable(struct ena_adapter *adapter, bool enable) { }
+static inline bool ena_phc_is_enabled(struct ena_adapter *adapter) { return false; }
+static inline bool ena_phc_is_active(struct ena_adapter *adapter) { return false; }
 static inline int ena_phc_get_index(struct ena_adapter *adapter) { return -1; }
 static inline int ena_phc_init(struct ena_adapter *adapter) { return 0; }
 static inline void ena_phc_destroy(struct ena_adapter *adapter) { }
-
+static inline int ena_phc_alloc(struct ena_adapter *adapter) { return 0; }
+static inline void ena_phc_free(struct ena_adapter *adapter) { }
 #endif /* ENA_PHC_SUPPORT */
 
 #endif /* ENA_PHC_H */
